@@ -67,7 +67,7 @@ $target %dowhat readsweeps $max_processes $computype $calcprocedure %specularrat
 toil genstar solvestar integratebox filterbox__ clean
 );
 
-$VERSION = '0.179';
+$VERSION = '0.181';
 $ABSTRACT = 'Sim::OPT is an optimization and parametric exploration program oriented to problem decomposition. It can be used with simulation programs receiving text files as input and emitting text files as output. It allows a free mix of sequential and parallel block coordinate searches.';
 
 #################################################################################
@@ -1170,14 +1170,14 @@ sub takewinning
 
 sub sense
 {
-	say $tee "WORKING.";
+	#say $tee "WORKING.";
 	my ( $addr, $mypath, $objcolumn, $stopcondition ) = @_;
-	say $tee "IN SENSE \$addr: " . dump( $addr );
-	say $tee "IN SENSE \$mypath: " . dump( $mypath );
-	say $tee "IN SENSE \$objcolumn: " . dump( $objcolumn );
-	say $tee "IN SENSE \$stopcondition: " . dump( $stopcondition );
+	#say $tee "IN SENSE \$addr: " . dump( $addr );
+	#say $tee "IN SENSE \$mypath: " . dump( $mypath );
+	#say $tee "IN SENSE \$objcolumn: " . dump( $objcolumn );
+	#say $tee "IN SENSE \$stopcondition: " . dump( $stopcondition );
 
-	my $newaddr = "$mypath/$addr" . "_variances.csv"; say $tee "IN SENSE \$newaddr: " . dump( $newaddr );
+	my $newaddr = "$mypath/$addr" . "_variances.csv"; #say $tee "IN SENSE \$newaddr: " . dump( $newaddr );
 
 	open( ADDR, "$addr" ) or die;
 	my @lines = <ADDR>;
@@ -1192,17 +1192,17 @@ sub sense
 
 	#say $tee "IN SENSE \@lines: " . dump( @lines );
 
-	my @values = map { ( split( ',', $_ ))[ $objcolumn ] } @purelines; say $tee "IN SENSE \@values: " . dump( @values );
-	my $totvariance = variance( @values ); say $tee "IN SENSE \$totvariance: $totvariance" ;
+	my @values = map { ( split( ',', $_ ))[ $objcolumn ] } @purelines; #say $tee "IN SENSE \@values: " . dump( @values );
+	my $totvariance = variance( @values ); #say $tee "IN SENSE \$totvariance: $totvariance" ;
 
-	my @cases = map { ( split( ',', $_ ))[0] } @purelines; say $tee "IN SENSE \@cases: " . dump( @cases );
+	my @cases = map { ( split( ',', $_ ))[0] } @purelines; #say $tee "IN SENSE \@cases: " . dump( @cases );
 
 	my @sack;
 	foreach my $case ( @cases )
 	{
 		my @row = split( "_", $case );
 		push( @sack, [ @row ] );
-	} say $tee "IN SENSE \@sack: " . dump( @sack );
+	} #say $tee "IN SENSE \@sack: " . dump( @sack );
 
 	my %whole;
 	my $count = 0;
@@ -1215,25 +1215,25 @@ sub sense
 			push( @{ $whole{$key}{$value} }, $values[$count] );
 		}
 		$count++;
-	} say $tee "IN SENSE \%whole: " . dump( \%whole );
+	} #say $tee "IN SENSE \%whole: " . dump( \%whole );
 
 	my ( %sensfs, %avgsensfs );
-	say $tee "IN SENSE keys \%whole: " . dump( keys %whole );
+	#say $tee "IN SENSE keys \%whole: " . dump( keys %whole );
 	foreach my $factor ( keys %whole )
 	{
-		say $tee "IN SENSE \$factor: " . dump( $factor );
-		my @avgvar; say $tee "IN SENSE keys %{ \$whole{\$factor} }: " . dump( keys %{ $whole{$factor} } );
+		#say $tee "IN SENSE \$factor: " . dump( $factor );
+		my @avgvar; #say $tee "IN SENSE keys %{ \$whole{\$factor} }: " . dump( keys %{ $whole{$factor} } );
 		foreach my $level ( keys %{ $whole{$factor} } )
 		{
-			say $tee "IN SENSE \$level: " . dump( $level );
-			my $variance = variance( @{ $whole{$factor}{$level} } ); say $tee "IN SENSE \$variance: $variance" ;
-			my $variancerat = ( $variance / $totvariance ); say $tee "IN SENSE \$variancerat: $variancerat" ;
+			#say $tee "IN SENSE \$level: " . dump( $level );
+			my $variance = variance( @{ $whole{$factor}{$level} } ); #say $tee "IN SENSE \$variance: $variance" ;
+			my $variancerat = ( $variance / $totvariance ); #say $tee "IN SENSE \$variancerat: $variancerat" ;
 			$sensfs{$factor}{$level} = $variancerat;
 			push( @avgsensf, $variancerat );
 		}
 		my $mean = mean( @avgsensf );
-		$avgsensfs{$factor} = $mean; say $tee "IN SENSE \$mean: " . dump( $mean );
-	} say $tee "IN SENSE \%sensfs: " . dump( \%sensfs ); say $tee "IN SENSE \%avgsensfs: " . dump( \%avgsensfs );
+		$avgsensfs{$factor} = $mean; #say $tee "IN SENSE \$mean: " . dump( $mean );
+	} #say $tee "IN SENSE \%sensfs: " . dump( \%sensfs ); say $tee "IN SENSE \%avgsensfs: " . dump( \%avgsensfs );
 
 	open( NEWADDR, ">$newaddr" ) or die;
 	foreach my $fact ( sort{ $a <=> $b }( keys %avgsensfs ) )
