@@ -36,9 +36,9 @@ no warnings;
 @ISA = qw(Exporter); # our @adamkISA = qw(Exporter);
 #%EXPORT_TAGS = ( DEFAULT => [qw( &opt &prepare )]); # our %EXPORT_TAGS = ( 'all' => [ qw( ) ] );
 #@EXPORT   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-our @EXPORT = qw( descend ); # our @EXPORT = qw( );
+our @EXPORT = qw( descend sense ); # our @EXPORT = qw( );
 
-$VERSION = '0.117'; # our $VERSION = '';
+$VERSION = '0.121'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent.';
 
 #########################################################################################
@@ -141,6 +141,10 @@ sub descend
 
   if ( $countcase > $#sweeps )# NUMBER OF CASES OF THE CURRENT PROBLEM
   {
+    if ( $dirfiles{checksensitivity} eq "yes" )
+    {
+      Sim::OPT::sense( $dirfiles{ordtot}, $mypath, $dowhat{objectivecolumn} );
+    }
     exit(say $tee "#END RUN.");
   }
 
@@ -227,7 +231,7 @@ sub descend
   if ( not( $sortmixed ) ){ die; }
 
   my ( $entryfile, $exitfile, $orderedfile );
-  my $entryname = $dirfiles{entryname}; #say $tee "IN DESCEND \$entryname: " . dump( $entryname );
+  my $entryname = $dirfiles{entryname}; #say $tee "IN DESCEND \$entryname: " .exit dump( $entryname );
   if ( $entryname ne "" )
   {
     $entryfile = "$mypath/" . "$file" . "_tmp_" . "$entryname" . ".csv";
@@ -277,6 +281,9 @@ sub descend
 
   if ( $countcase > $#sweeps )# NUMBER OF CASES OF THE CURRENT PROBLEM
   {
+    {
+      Sim::OPT::sense( $dirfiles{ordtot}, $mypath, $dowhat{objectivecolumn} );
+    }
     exit(say $tee "#END RUN.");
   }
 
@@ -1458,6 +1465,10 @@ sub descend
 
         if ( $countcase > $#sweeps )# NUMBER OF CASES OF THE CURRENT PROBLEM
         {
+          if ( $dirfiles{checksensitivity} eq "yes" )
+          {
+            Sim::OPT::sense( $dirfiles{ordtot}, $mypath, $dowhat{objectivecolumn} );
+          }
           exit(say $tee "#END RUN.");
         }
 
@@ -1488,6 +1499,10 @@ sub descend
 
         if ( $countcase > $#sweeps )# NUMBER OF CASES OF THE CURRENT PROBLEM
         {
+          if ( $dirfiles{checksensitivity} eq "yes" )
+          {
+            Sim::OPT::sense( $dirfiles{ordtot}, $mypath, $dowhat{objectivecolumn} );
+          }
           exit(say $tee "#END RUN.");
         }
 
